# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dydxprotocol/delaymsg/block_message_ids.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-dydxprotocol/delaymsg/block_message_ids.proto\x12\x15\x64ydxprotocol.delaymsg\"\x1e\n\x0f\x42lockMessageIds\x12\x0b\n\x03ids\x18\x01 \x03(\rB<Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dydxprotocol.delaymsg.block_message_ids_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z:github.com/dydxprotocol/v4-chain/protocol/x/delaymsg/types'
  _globals['_BLOCKMESSAGEIDS']._serialized_start=72
  _globals['_BLOCKMESSAGEIDS']._serialized_end=102
# @@protoc_insertion_point(module_scope)
